@@ -73,16 +73,16 @@ from __future__ import annotations
 import json
 import re
 import uuid
-from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, TextIO, cast
-
-if TYPE_CHECKING:
-    from collections.abc import Generator
 from collections import defaultdict
+from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, TextIO, cast
 
 from translate.lang.data import cldr_plural_categories
 from translate.misc.multistring import multistring
 from translate.storage import base
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+
 
 class BaseJsonUnit(base.DictUnit):
     """A JSON entry."""
@@ -745,10 +745,10 @@ class GoI18NJsonFile(JsonFile):
                             if key in translation
                         ]
                     )
-                except ValueError:
+                except ValueError as error:
                     raise ValueError(
                         f'"{id}" is an object but does not contain plurals. Maybe this is not a go-i18n JSON file?'
-                    )
+                    ) from error
             unit = self.UnitClass(
                 translation,
                 value.get("id", ""),
@@ -818,10 +818,10 @@ class GoI18NV2JsonFile(JsonFile):
                             if key in value
                         ]
                     )
-                except ValueError:
+                except ValueError as error:
                     raise ValueError(
                         f'"{id}" is an object but does not contain plurals. Maybe this is not a go-i18n v2 JSON file?'
-                    )
+                    ) from error
                 unit = self.UnitClass(
                     translation,
                     id,
